summaryrefslogtreecommitdiffstats
path: root/src/knutdock.cpp
diff options
context:
space:
mode:
Diffstat (limited to 'src/knutdock.cpp')
-rwxr-xr-xsrc/knutdock.cpp20
1 files changed, 10 insertions, 10 deletions
diff --git a/src/knutdock.cpp b/src/knutdock.cpp
index a404221..bb1f6e1 100755
--- a/src/knutdock.cpp
+++ b/src/knutdock.cpp
@@ -152,7 +152,7 @@ void KNutDock::changeKIcon (void) {
if (!m_runtimeLayer) {
m_runtimeLayer = new TQPixmap(ICON_SIZE,ICON_SIZE);
}
- painttqStatus(m_statusValue);
+ paintStatus(m_statusValue);
paintRuntime(m_runtimeValue, m_statusValue);
}
else { // picture Icon
@@ -195,7 +195,7 @@ void KNutDock::repaintDock (const bool always) {
TQPainter paint;
- if (m_activeUpsInfo->upsNet == 0) { tqrepaint(); return;}
+ if (m_activeUpsInfo->upsNet == 0) { repaint(); return;}
m_dataOkOld=m_dataOk;
@@ -215,7 +215,7 @@ void KNutDock::repaintDock (const bool always) {
}
else myRuntimeValue = knc::numberVarError;
- myStatusValue = m_activeUpsInfo->upsNet->readtqStatus();
+ myStatusValue = m_activeUpsInfo->upsNet->readStatus();
switch (m_typeOfIcon) {
@@ -223,14 +223,14 @@ void KNutDock::repaintDock (const bool always) {
// *********STATUS****************
if (myStatusValue !=m_statusValue ) {
m_statusValue = myStatusValue;
- painttqStatus(m_statusValue);
+ paintStatus(m_statusValue);
repaintNow = true;
}
// **********RUNTIME***********
myStatusBatValue = myStatusValue & KNutNet::OB; // OB = UPS runs on battery
if ((myRuntimeValue != m_runtimeValue) || (myStatusBatValue != m_statusBatValue)) {
// when runtime is changed or flags OB is changed we must tqrepaint icons
// when OB is changed same items in icon will change color
m_runtimeValue = myRuntimeValue; // runtime is old value of runtime, one is defined like global value of class
m_statusBatValue = myStatusBatValue;
@@ -390,7 +390,7 @@ void KNutDock::repaintDock (const bool always) {
}
}
}
- tqrepaint();
+ repaint();
}
@@ -483,17 +483,17 @@ void KNutDock::toolTip (int runtime, int status, int batteryCharge, int upsLoad
if (m_toolTipFlags & TTRun) {
if (runtime != knc::numberVarError)
- text += "\n" + i18n("Runtime") + i18n(" : %1:%2 min").tqarg(min).tqarg(sec);
+ text += "\n" + i18n("Runtime") + i18n(" : %1:%2 min").arg(min).arg(sec);
}
if (m_toolTipFlags & TTCharge) {
if (batteryCharge != knc::numberVarError)
- text += "\n" + i18n("Battery Charge") + TQString(" : %1 %").tqarg(batteryCharge);
+ text += "\n" + i18n("Battery Charge") + TQString(" : %1 %").arg(batteryCharge);
}
if (m_toolTipFlags & TTLoad) {
if (upsLoad != knc::numberVarError)
- text += "\n" + i18n("UPS Load") + TQString(" : %1 %").tqarg(upsLoad);
+ text += "\n" + i18n("UPS Load") + TQString(" : %1 %").arg(upsLoad);
}
TQToolTip::remove(this);
@@ -726,7 +726,7 @@ void KNutDock::paintOKPoint (TQPainter& paint ) {
}
-void KNutDock::painttqStatus (int status ) {
+void KNutDock::paintStatus (int status ) {
TQPainter paint;
int lastPos = 0;
@@ -223,14 +223,14 @@ void KNutDock::repaintDock (const bool always) {
myStatusBatValue = myStatusValue & KNutNet::OB; // OB = UPS runs on battery
if ((myRuntimeValue != m_runtimeValue) || (myStatusBatValue != m_statusBatValue)) {
- // when runtime is changed or flags OB is changed we must tqrepaint icons
+ // when runtime is changed or flags OB is changed we must repaint icons
// when OB is changed same items in icon will change color
m_runtimeValue = myRuntimeValue; // runtime is old value of runtime, one is defined like global value of class